import 'package:flutter/material.dart';

class NamesFormField extends StatelessWidget {
  final TextEditingController firstNameController;
  final TextEditingController lastNameController;
  final Function? lastNameValidator;
  final Function? firstNameValidator;
  final Function onChangedFirstName;
  final Function onChangedLastName;
  final FocusNode? nextFocusNode;
  final FocusNode betweenFocus = new FocusNode();
  final FocusNode? focusNode;
  final double middleSpacing;
  final String firstNameLabelText;
  final String lastNameLabelText;

  NamesFormField({
    required this.firstNameController,
    required this.lastNameController,
    this.firstNameValidator,
    this.lastNameValidator,
    required this.onChangedFirstName,
    required this.onChangedLastName,
    this.focusNode,
    this.nextFocusNode,
    this.middleSpacing = 25,
    this.firstNameLabelText = "First name",
    this.lastNameLabelText = "Last name",
  });

  @override
  Widget build(BuildContext context) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      children: [
        Expanded(
          child: TextFormField(
            controller: firstNameController,
            textCapitalization: TextCapitalization.words,
            keyboardType: TextInputType.name,
            autocorrect: false,
            focusNode: focusNode,
            onEditingComplete: () => FocusScope.of(context).requestFocus(betweenFocus),
            onChanged: (value) => onChangedFirstName(value),
            validator: (value) => firstNameValidator != null ? firstNameValidator!(value) : nameValidator(value!),
            decoration: InputDecoration(
              labelText: "First name",
            ),
          ),
        ),
        SizedBox(width: middleSpacing,),
        Expanded(
          child: TextFormField(
            controller: lastNameController,
            textCapitalization: TextCapitalization.words,
            keyboardType: TextInputType.name,
            autocorrect: false,
            focusNode: betweenFocus,
            onEditingComplete: () => nextFocusNode == null ? FocusScope.of(context).unfocus() : FocusScope.of(context).requestFocus(nextFocusNode),
            onChanged: (value) => onChangedLastName(value),
            validator: (value) => lastNameValidator != null ? lastNameValidator!(value) : nameValidator(value!),
            decoration: InputDecoration(
              labelText: "Last name",
            ),
          ),
        ),
      ],
    );
  }

  String? nameValidator(String input) {
    if (input.isEmpty) {
      return "Can't be empty";
    }
    return null;
  }
}