import 'package:flutter/material.dart';

class PasswordFormField extends StatelessWidget {
  final TextEditingController controller;
  final String labelText;
  late Function passwordValidator;
  Function? onChanged;
  final FocusNode? nextFocusNode;
  final FocusNode? focusNode;

  PasswordFormField({
    required this.controller,
    this.labelText = "Password",
    this.passwordValidator = _passwordValidator,
    this.onChanged,
    this.nextFocusNode,
    this.focusNode,
  });

  @override
  Widget build(BuildContext context) {
    if (this.onChanged == null) {
      this.onChanged = (value) => { };
    }
    return TextFormField(
      controller: controller,
      textCapitalization: TextCapitalization.none,
      keyboardType: TextInputType.text,
      autocorrect: false,
      obscureText: true,
      focusNode: focusNode,
      onEditingComplete: () => nextFocusNode == null ? FocusScope.of(context).unfocus() : FocusScope.of(context).requestFocus(nextFocusNode),
      onChanged: (value) => onChanged!(value),
      validator: (value) => passwordValidator(value),
      decoration: InputDecoration(
        icon: Icon(Icons.lock),
        labelText: labelText,
      ),
    );
  }

  static String? _passwordValidator(String input) {
    if (input.trim().isEmpty) {
      return 'Enter your password';
    }
    return null;
  }
}
